XMap

Struct XMap 

pub struct XMap {
    pub task: Signature,
    pub argsets: Vec<Vec<Value>>,
    pub fail_fast: bool,
}
XMap: Map with exception handling

Like Map, but continues processing even if some tasks fail. Failed tasks are tracked separately.

Fields

task: Signature

Task to apply

argsets: Vec<Vec<Value>>

List of argument sets

fail_fast: bool

Whether to stop on first error

Implementations

Source

impl XMap

pub fn new(task: Signature, argsets: Vec<Vec<Value>>) -> XMap

Create a new XMap workflow

pub fn fail_fast(self, fail_fast: bool) -> XMap

Set fail-fast behavior (stop on first error)

pub fn is_empty(&self) -> bool

Check if empty

pub fn len(&self) -> usize

Get number of argument sets

pub async fn apply<B>(self, broker: &B) -> Result<Uuid, CanvasError>
where B: Broker,

Apply the xmap by creating a group of tasks

Note: Exception handling is done at the result collection level, not during task submission.